Module interfaces

Module interfaces 

Contains helpers for looking up system network interfaces.

Structs

DefaultRouteDetails
The details about a default route.
HomeRouter
Likely IPs of the residentla router, and the ip address of the current machine using it.
Interface
Represents a network interface.
Ipv6AddrFlags
State flags for a single IPv6 address.
State
Intended to store the state of the machine’s network interfaces, routing table, and other network configuration. For now it’s pretty basic.

Enums

IpNet
Structure of an IP network, either IPv4 or IPv6.

Functions

default_route_interface
Like DefaultRoutDetails::new but only returns the interface name.