Struct LocalAddresses

pub struct LocalAddresses {
    pub loopback: Vec<IpAddr>,
    pub regular: Vec<IpAddr>,
}
List of machine’s IP addresses.

Fields

loopback: Vec<IpAddr>

Loopback addresses.

regular: Vec<IpAddr>

Regular addresses.

Implementations

Source

impl LocalAddresses

pub fn new() -> Self

Returns the machine’s IP addresses. If there are no regular addresses it will return any IPv4 linklocal or IPv6 unique local addresses because we know of environments where these are used with NAT to provide connectivity.